==> egg-forum-post-dal-1.0.0-20210930.072037-1-sources.jar: com/bxm/localnews/news/domain/recommend/RecommendMapper.java <==
package com.bxm.localnews.news.domain.recommend;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bxm.localnews.news.model.bo.RecommendBO;
import com.bxm.localnews.news.model.param.ForumPostListQueryParam;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface RecommendMapper {

    /**
     * 我的收藏列表，不包含已经删除的帖子
     */
    IPage<RecommendBO> queryMyCollect(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 我发布的帖子，分享给其他用户
     */
    IPage<RecommendBO> queryShareRelease(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询用户发布的帖子，如果是用户自己，则可以查看所有的帖子，除了删除的
     * 如果是其他人，则只能查询公开的部分
     */
    IPage<RecommendBO> queryUserRelease(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询当前用户关注的用户发布的内容
     */
    IPage<RecommendBO> queryFollowList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询本地圈首页推荐信息
     */
    IPage<RecommendBO> queryLocalIndexList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询话题下的热门内容
     */
    IPage<RecommendBO> queryTopicHotIndexList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询话题下的新内容
     */
    IPage<RecommendBO> queryTopicNewIndexList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

}

==> egg-forum-post-dal-2.0.4-sources.jar: com/bxm/localnews/news/domain/recommend/RecommendMapper.java <==
package com.bxm.localnews.news.domain.recommend;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bxm.localnews.news.model.bo.RecommendBO;
import com.bxm.localnews.news.model.param.ForumPostListQueryParam;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface RecommendMapper {

    /**
     * 我的收藏列表，不包含已经删除的帖子
     */
    IPage<RecommendBO> queryMyCollect(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 我发布的帖子，分享给其他用户
     */
    IPage<RecommendBO> queryShareRelease(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询用户发布的帖子，如果是用户自己，则可以查看所有的帖子，除了删除的
     * 如果是其他人，则只能查询公开的部分
     */
    IPage<RecommendBO> queryUserRelease(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询当前用户关注的用户发布的内容
     */
    IPage<RecommendBO> queryFollowList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询本地圈首页推荐信息
     */
    IPage<RecommendBO> queryLocalIndexList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询话题下的热门内容
     */
    IPage<RecommendBO> queryTopicHotIndexList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询话题下的新内容
     */
    IPage<RecommendBO> queryTopicNewIndexList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

    /**
     * 查询所有符合条件的处于推广状态的开仓放粮的帖子
     */
    List<RecommendBO> queryGrainPostList(@Param("param") ForumPostListQueryParam param);

    /**
     * 根据发放的粮食数量获取开仓放粮的帖子
     *
     * @param page  分页参数
     * @param param 查询参数
     * @return 分页结果
     */
    List<RecommendBO> queryGrainPostSortList(@Param("page") Page<RecommendBO> page, @Param("param") ForumPostListQueryParam param);

}
